@@ -20,7 +20,7 @@ from simpledate.utils import DebugLog, MRUSortedIterable, OrderedSet, set_kargs_
 # Build the various formats used by SimpleDateParser.
 
 RFC_2822 = EMAIL = (invert('(!a!, ?)d! ?b! ?Y! H:M(:S)?(! !Z|! ?z)?'),)
-ISO_8601 = YMD = (invert('Y(!-?m(!-?d((! |%T)H!:M(!:S(.f)?)?)?)?)?(! !Z|! ?z)?'),)
+ISO_8601 = YMD = (invert('Y(!-?m(!-?d((! |%T)H!:?M(!:?S(.f)?)?)?)?)?(! !Z|! ?z)?'),)
 MDY = (invert('(m!/d!/)?Y(! H!:M(!:S(.f)?)?)?(! !Z|! ?z)?'),)
 DMY = (invert('(d!/m!/)?Y(! H!:M(!:S(.f)?)?)?(! !Z|! ?z)?'),)
 
